"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DeviceView:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeviceViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeviceView.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BASIC: _DeviceView.ValueType  # 0
    """Server responses without monitoring data.
    The default value.
    """
    FULL: _DeviceView.ValueType  # 1
    """Server responses with monitoring data."""

class DeviceView(_DeviceView, metaclass=_DeviceViewEnumTypeWrapper): ...

BASIC: DeviceView.ValueType  # 0
"""Server responses without monitoring data.
The default value.
"""
FULL: DeviceView.ValueType  # 1
"""Server responses with monitoring data."""
global___DeviceView = DeviceView

@typing.final
class Device(google.protobuf.message.Message):
    """A device. For more information, see [Device](/docs/iot-core/concepts/index#device)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Device._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Device._Status.ValueType  # 0
        CREATING: Device._Status.ValueType  # 1
        """Device is being created."""
        ACTIVE: Device._Status.ValueType  # 2
        """Device is ready to use."""
        DELETING: Device._Status.ValueType  # 3
        """Device is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Device.Status.ValueType  # 0
    CREATING: Device.Status.ValueType  # 1
    """Device is being created."""
    ACTIVE: Device.Status.ValueType  # 2
    """Device is ready to use."""
    DELETING: Device.Status.ValueType  # 3
    """Device is being deleted."""

    @typing.final
    class TopicAliasesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    REGISTRY_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TOPIC_ALIASES_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MONITORING_DATA_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the device."""
    registry_id: builtins.str
    """ID of the registry that the device belongs to."""
    name: builtins.str
    """Name of the device. The name is unique within the registry."""
    description: builtins.str
    """Description of the device. 0-256 characters long."""
    status: global___Device.Status.ValueType
    """Status of the device."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def topic_aliases(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Alias of a device topic.

        Alias is an alternate name of a device topic assigned by the user. Map alias to canonical topic name prefix, e.g. `my/custom/alias` match to `$device/abcdef/events`.
        """

    @property
    def monitoring_data(self) -> global___DeviceMonitoringData:
        """Device monitoring data, returns if FULL view specified."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        registry_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        topic_aliases: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___Device.Status.ValueType = ...,
        monitoring_data: global___DeviceMonitoringData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "monitoring_data", b"monitoring_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "id", b"id", "monitoring_data", b"monitoring_data", "name", b"name", "registry_id", b"registry_id", "status", b"status", "topic_aliases", b"topic_aliases"]) -> None: ...

global___Device = Device

@typing.final
class DeviceCertificate(google.protobuf.message.Message):
    """A device certificate. For more information, see [Managing device certificates](/docs/iot-core/operations/certificates/device-certificates)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    CERTIFICATE_DATA_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device that the certificate belongs to."""
    fingerprint: builtins.str
    """SHA256 hash of the certificate."""
    certificate_data: builtins.str
    """Public part of the certificate."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        fingerprint: builtins.str = ...,
        certificate_data: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["certificate_data", b"certificate_data", "created_at", b"created_at", "device_id", b"device_id", "fingerprint", b"fingerprint"]) -> None: ...

global___DeviceCertificate = DeviceCertificate

@typing.final
class DevicePassword(google.protobuf.message.Message):
    """A device password."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_ID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    device_id: builtins.str
    """ID of the device that the password belongs to."""
    id: builtins.str
    """ID of the password."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    def __init__(
        self,
        *,
        device_id: builtins.str = ...,
        id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "device_id", b"device_id", "id", b"id"]) -> None: ...

global___DevicePassword = DevicePassword

@typing.final
class DeviceMonitoringData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_AUTH_IP_FIELD_NUMBER: builtins.int
    LAST_AUTH_TIME_FIELD_NUMBER: builtins.int
    LAST_PUB_ACTIVITY_TIME_FIELD_NUMBER: builtins.int
    LAST_SUB_ACTIVITY_TIME_FIELD_NUMBER: builtins.int
    LAST_ONLINE_TIME_FIELD_NUMBER: builtins.int
    last_auth_ip: builtins.str
    @property
    def last_auth_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_pub_activity_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_sub_activity_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_online_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        last_auth_ip: builtins.str = ...,
        last_auth_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_pub_activity_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_sub_activity_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_online_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["last_auth_time", b"last_auth_time", "last_online_time", b"last_online_time", "last_pub_activity_time", b"last_pub_activity_time", "last_sub_activity_time", b"last_sub_activity_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["last_auth_ip", b"last_auth_ip", "last_auth_time", b"last_auth_time", "last_online_time", b"last_online_time", "last_pub_activity_time", b"last_pub_activity_time", "last_sub_activity_time", b"last_sub_activity_time"]) -> None: ...

global___DeviceMonitoringData = DeviceMonitoringData



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/vpc/v1/privatelink/private_endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.vpc.v1.privatelink import private_endpoint_pb2 as yandex_dot_cloud_dot_vpc_dot_v1_dot_privatelink_dot_private__endpoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/vpc/v1/privatelink/private_endpoint_service.proto\x12\x1fyandex.cloud.vpc.v1.privatelink\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x36yandex/cloud/vpc/v1/privatelink/private_endpoint.proto\"F\n\x19GetPrivateEndpointRequest\x12)\n\x13private_endpoint_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"K\n\x17InternalIpv4AddressSpec\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"\x8e\x01\n\x0b\x41\x64\x64ressSpec\x12\x14\n\naddress_id\x18\x01 \x01(\tH\x00\x12^\n\x1ainternal_ipv4_address_spec\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.vpc.v1.privatelink.InternalIpv4AddressSpecH\x00\x42\t\n\x07\x61\x64\x64ress\"\x8c\x05\n\x1c\x43reatePrivateEndpointRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9e\x01\n\x06labels\x18\x04 \x03(\x0b\x32I.yandex.cloud.vpc.v1.privatelink.CreatePrivateEndpointRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12 \n\nnetwork_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x42\n\x0c\x61\x64\x64ress_spec\x18\x06 \x01(\x0b\x32,.yandex.cloud.vpc.v1.privatelink.AddressSpec\x12P\n\x0b\x64ns_options\x18\x08 \x01(\x0b\x32;.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.DnsOptions\x12X\n\x0eobject_storage\x18\t \x01(\x0b\x32>.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.ObjectStorageH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\x07service\x12\x04\xc0\xc1\x31\x01J\x04\x08\x07\x10\x08\"<\n\x1d\x43reatePrivateEndpointMetadata\x12\x1b\n\x13private_endpoint_id\x18\x01 \x01(\t\"\xba\x04\n\x1cUpdatePrivateEndpointRequest\x12)\n\x13private_endpoint_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9e\x01\n\x06labels\x18\x05 \x03(\x0b\x32I.yandex.cloud.vpc.v1.privatelink.UpdatePrivateEndpointRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x42\n\x0c\x61\x64\x64ress_spec\x18\x06 \x01(\x0b\x32,.yandex.cloud.vpc.v1.privatelink.AddressSpec\x12P\n\x0b\x64ns_options\x18\x08 \x01(\x0b\x32;.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint.DnsOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\x08\"<\n\x1dUpdatePrivateEndpointMetadata\x12\x1b\n\x13private_endpoint_id\x18\x01 \x01(\t\"I\n\x1c\x44\x65letePrivateEndpointRequest\x12)\n\x13private_endpoint_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1d\x44\x65letePrivateEndpointMetadata\x12\x1b\n\x13private_endpoint_id\x18\x01 \x01(\t\"\xb0\x01\n\x1bListPrivateEndpointsRequest\x12\x1d\n\tfolder_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000B\x11\n\tcontainer\x12\x04\xc0\xc1\x31\x01J\x04\x08\x02\x10\x03\"\x84\x01\n\x1cListPrivateEndpointsResponse\x12K\n\x11private_endpoints\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x90\x01\n$ListPrivateEndpointOperationsRequest\x12)\n\x13private_endpoint_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"w\n%ListPrivateEndpointOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xaa\t\n\x16PrivateEndpointService\x12\xa4\x01\n\x03Get\x12:.yandex.cloud.vpc.v1.privatelink.GetPrivateEndpointRequest\x1a\x30.yandex.cloud.vpc.v1.privatelink.PrivateEndpoint\"/\x82\xd3\xe4\x93\x02)\x12\'/vpc/v1/endpoints/{private_endpoint_id}\x12\x9e\x01\n\x04List\x12<.yandex.cloud.vpc.v1.privatelink.ListPrivateEndpointsRequest\x1a=.yandex.cloud.vpc.v1.privatelink.ListPrivateEndpointsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/vpc/v1/endpoints\x12\xbc\x01\n\x06\x43reate\x12=.yandex.cloud.vpc.v1.privatelink.CreatePrivateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*0\n\x1d\x43reatePrivateEndpointMetadata\x12\x0fPrivateEndpoint\x82\xd3\xe4\x93\x02\x16\"\x11/vpc/v1/endpoints:\x01*\x12\xd2\x01\n\x06Update\x12=.yandex.cloud.vpc.v1.privatelink.UpdatePrivateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*0\n\x1dUpdatePrivateEndpointMetadata\x12\x0fPrivateEndpoint\x82\xd3\xe4\x93\x02,2\'/vpc/v1/endpoints/{private_endpoint_id}:\x01*\x12\xd5\x01\n\x06\x44\x65lete\x12=.yandex.cloud.vpc.v1.privatelink.DeletePrivateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*6\n\x1d\x44\x65letePrivateEndpointMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02)*\'/vpc/v1/endpoints/{private_endpoint_id}\x12\xdb\x01\n\x0eListOperations\x12\x45.yandex.cloud.vpc.v1.privatelink.ListPrivateEndpointOperationsRequest\x1a\x46.yandex.cloud.vpc.v1.privatelink.ListPrivateEndpointOperationsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/vpc/v1/endpoints/{private_endpoint_id}/operationsBv\n#yandex.cloud.api.vpc.v1.privatelinkZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1/privatelink;privatelinkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.vpc.v1.privatelink.private_endpoint_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.vpc.v1.privatelinkZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/vpc/v1/privatelink;privatelink'
  _GETPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._options = None
  _GETPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _INTERNALIPV4ADDRESSSPEC.fields_by_name['subnet_id']._options = None
  _INTERNALIPV4ADDRESSSPEC.fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPRIVATEENDPOINTREQUEST_LABELSENTRY._options = None
  _CREATEPRIVATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEPRIVATEENDPOINTREQUEST.oneofs_by_name['service']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.oneofs_by_name['service']._serialized_options = b'\300\3011\001'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['folder_id']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['name']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['description']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['labels']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['network_id']._options = None
  _CREATEPRIVATEENDPOINTREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPRIVATEENDPOINTREQUEST_LABELSENTRY._options = None
  _UPDATEPRIVATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._options = None
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['name']._options = None
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['description']._options = None
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['labels']._options = None
  _UPDATEPRIVATEENDPOINTREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETEPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._options = None
  _DELETEPRIVATEENDPOINTREQUEST.fields_by_name['private_endpoint_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPRIVATEENDPOINTSREQUEST.oneofs_by_name['container']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.oneofs_by_name['container']._serialized_options = b'\300\3011\001'
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['folder_id']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['page_size']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['page_token']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['filter']._options = None
  _LISTPRIVATEENDPOINTSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['private_endpoint_id']._options = None
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['private_endpoint_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTPRIVATEENDPOINTOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=1000'
  _PRIVATEENDPOINTSERVICE.methods_by_name['Get']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002)\022\'/vpc/v1/endpoints/{private_endpoint_id}'
  _PRIVATEENDPOINTSERVICE.methods_by_name['List']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/vpc/v1/endpoints'
  _PRIVATEENDPOINTSERVICE.methods_by_name['Create']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreatePrivateEndpointMetadata\022\017PrivateEndpoint\202\323\344\223\002\026\"\021/vpc/v1/endpoints:\001*'
  _PRIVATEENDPOINTSERVICE.methods_by_name['Update']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdatePrivateEndpointMetadata\022\017PrivateEndpoint\202\323\344\223\002,2\'/vpc/v1/endpoints/{private_endpoint_id}:\001*'
  _PRIVATEENDPOINTSERVICE.methods_by_name['Delete']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeletePrivateEndpointMetadata\022\025google.protobuf.Empty\202\323\344\223\002)*\'/vpc/v1/endpoints/{private_endpoint_id}'
  _PRIVATEENDPOINTSERVICE.methods_by_name['ListOperations']._options = None
  _PRIVATEENDPOINTSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0024\0222/vpc/v1/endpoints/{private_endpoint_id}/operations'
  _globals['_GETPRIVATEENDPOINTREQUEST']._serialized_start=324
  _globals['_GETPRIVATEENDPOINTREQUEST']._serialized_end=394
  _globals['_INTERNALIPV4ADDRESSSPEC']._serialized_start=396
  _globals['_INTERNALIPV4ADDRESSSPEC']._serialized_end=471
  _globals['_ADDRESSSPEC']._serialized_start=474
  _globals['_ADDRESSSPEC']._serialized_end=616
  _globals['_CREATEPRIVATEENDPOINTREQUEST']._serialized_start=619
  _globals['_CREATEPRIVATEENDPOINTREQUEST']._serialized_end=1271
  _globals['_CREATEPRIVATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=1203
  _globals['_CREATEPRIVATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=1248
  _globals['_CREATEPRIVATEENDPOINTMETADATA']._serialized_start=1273
  _globals['_CREATEPRIVATEENDPOINTMETADATA']._serialized_end=1333
  _globals['_UPDATEPRIVATEENDPOINTREQUEST']._serialized_start=1336
  _globals['_UPDATEPRIVATEENDPOINTREQUEST']._serialized_end=1906
  _globals['_UPDATEPRIVATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=1203
  _globals['_UPDATEPRIVATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=1248
  _globals['_UPDATEPRIVATEENDPOINTMETADATA']._serialized_start=1908
  _globals['_UPDATEPRIVATEENDPOINTMETADATA']._serialized_end=1968
  _globals['_DELETEPRIVATEENDPOINTREQUEST']._serialized_start=1970
  _globals['_DELETEPRIVATEENDPOINTREQUEST']._serialized_end=2043
  _globals['_DELETEPRIVATEENDPOINTMETADATA']._serialized_start=2045
  _globals['_DELETEPRIVATEENDPOINTMETADATA']._serialized_end=2105
  _globals['_LISTPRIVATEENDPOINTSREQUEST']._serialized_start=2108
  _globals['_LISTPRIVATEENDPOINTSREQUEST']._serialized_end=2284
  _globals['_LISTPRIVATEENDPOINTSRESPONSE']._serialized_start=2287
  _globals['_LISTPRIVATEENDPOINTSRESPONSE']._serialized_end=2419
  _globals['_LISTPRIVATEENDPOINTOPERATIONSREQUEST']._serialized_start=2422
  _globals['_LISTPRIVATEENDPOINTOPERATIONSREQUEST']._serialized_end=2566
  _globals['_LISTPRIVATEENDPOINTOPERATIONSRESPONSE']._serialized_start=2568
  _globals['_LISTPRIVATEENDPOINTOPERATIONSRESPONSE']._serialized_end=2687
  _globals['_PRIVATEENDPOINTSERVICE']._serialized_start=2690
  _globals['_PRIVATEENDPOINTSERVICE']._serialized_end=3884
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/backend_group.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.apploadbalancer.v1 import payload_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_payload__pb2
from yandex.cloud.apploadbalancer.v1 import tls_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_tls__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/apploadbalancer/v1/backend_group.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yandex/cloud/apploadbalancer/v1/payload.proto\x1a)yandex/cloud/apploadbalancer/v1/tls.proto\x1a\x1dyandex/cloud/validation.proto\"\xd8\x03\n\x0c\x42\x61\x63kendGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12I\n\x06labels\x18\x05 \x03(\x0b\x32\x39.yandex.cloud.apploadbalancer.v1.BackendGroup.LabelsEntry\x12\x41\n\x04http\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.HttpBackendGroupH\x00\x12\x41\n\x04grpc\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.GrpcBackendGroupH\x00\x12\x45\n\x06stream\x18\n \x01(\x0b\x32\x33.yandex.cloud.apploadbalancer.v1.StreamBackendGroupH\x00\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x62\x61\x63kendJ\x04\x08\x08\x10\t\"\xbc\x01\n\x12StreamBackendGroup\x12@\n\x08\x62\x61\x63kends\x18\x01 \x03(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamBackend\x12P\n\nconnection\x18\x02 \x01(\x0b\x32:.yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinityH\x00\x42\x12\n\x10session_affinity\"\xcc\x02\n\x10HttpBackendGroup\x12>\n\x08\x62\x61\x63kends\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpBackend\x12P\n\nconnection\x18\x02 \x01(\x0b\x32:.yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinityH\x00\x12H\n\x06header\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.apploadbalancer.v1.HeaderSessionAffinityH\x00\x12H\n\x06\x63ookie\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.apploadbalancer.v1.CookieSessionAffinityH\x00\x42\x12\n\x10session_affinity\"\xcc\x02\n\x10GrpcBackendGroup\x12>\n\x08\x62\x61\x63kends\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.GrpcBackend\x12P\n\nconnection\x18\x02 \x01(\x0b\x32:.yandex.cloud.apploadbalancer.v1.ConnectionSessionAffinityH\x00\x12H\n\x06header\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.apploadbalancer.v1.HeaderSessionAffinityH\x00\x12H\n\x06\x63ookie\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.apploadbalancer.v1.CookieSessionAffinityH\x00\x42\x12\n\x10session_affinity\"7\n\x15HeaderSessionAffinity\x12\x1e\n\x0bheader_name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x31-256\"X\n\x15\x43ookieSessionAffinity\x12\x17\n\x04name\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05\x31-256\x12&\n\x03ttl\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\".\n\x19\x43onnectionSessionAffinity\x12\x11\n\tsource_ip\x18\x01 \x01(\x08\"\xc7\x01\n\x13LoadBalancingConfig\x12\"\n\x0fpanic_threshold\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x31\n\x1elocality_aware_routing_percent\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x17\n\x0fstrict_locality\x18\x03 \x01(\x08\x12@\n\x04mode\x18\x04 \x01(\x0e\x32\x32.yandex.cloud.apploadbalancer.v1.LoadBalancingMode\"\x97\x04\n\rStreamBackend\x12.\n\x04name\x18\x01 \x01(\tB \xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x33\n\x0e\x62\x61\x63kend_weight\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12S\n\x15load_balancing_config\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancingConfig\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12M\n\rtarget_groups\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.TargetGroupsBackendH\x00\x12\x42\n\x0chealthchecks\x18\x06 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HealthCheck\x12\x38\n\x03tls\x18\x07 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.BackendTls\x12\x1d\n\x15\x65nable_proxy_protocol\x18\x08 \x01(\x08\x12/\n\'keep_connections_on_host_health_failure\x18\t \x01(\x08\x42\x14\n\x0c\x62\x61\x63kend_type\x12\x04\xc0\xc1\x31\x01\"\xad\x04\n\x0bHttpBackend\x12\x32\n\x04name\x18\x01 \x01(\tB$\xe8\xc7\x31\x01\xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x33\n\x0e\x62\x61\x63kend_weight\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12S\n\x15load_balancing_config\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancingConfig\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12M\n\rtarget_groups\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.TargetGroupsBackendH\x00\x12O\n\x0estorage_bucket\x18\t \x01(\x0b\x32\x35.yandex.cloud.apploadbalancer.v1.StorageBucketBackendH\x00\x12\x42\n\x0chealthchecks\x18\x06 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HealthCheck\x12\x38\n\x03tls\x18\x07 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.BackendTls\x12\x11\n\tuse_http2\x18\x08 \x01(\x08\x42\x14\n\x0c\x62\x61\x63kend_type\x12\x04\xc0\xc1\x31\x01\"\xcf\x03\n\x0bGrpcBackend\x12\x32\n\x04name\x18\x01 \x01(\tB$\xe8\xc7\x31\x01\xf2\xc7\x31\x1c[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x33\n\x0e\x62\x61\x63kend_weight\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12S\n\x15load_balancing_config\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.LoadBalancingConfig\x12\x19\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12M\n\rtarget_groups\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.apploadbalancer.v1.TargetGroupsBackendH\x00\x12\x42\n\x0chealthchecks\x18\x07 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HealthCheck\x12\x38\n\x03tls\x18\x08 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.BackendTlsB\x14\n\x0c\x62\x61\x63kend_type\x12\x04\xc0\xc1\x31\x01J\x04\x08\x06\x10\x07\"7\n\x13TargetGroupsBackend\x12 \n\x10target_group_ids\x18\x01 \x03(\tB\x06\x82\xc8\x31\x02>0\"\x1c\n\x1aPlaintextTransportSettings\"|\n\x17SecureTransportSettings\x12\x0b\n\x03sni\x18\x01 \x01(\t\x12N\n\x12validation_context\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.apploadbalancer.v1.ValidationContextJ\x04\x08\x02\x10\x03\"o\n\nBackendTls\x12\x0b\n\x03sni\x18\x01 \x01(\t\x12N\n\x12validation_context\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.apploadbalancer.v1.ValidationContextJ\x04\x08\x02\x10\x03\",\n\x14StorageBucketBackend\x12\x14\n\x06\x62ucket\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xcc\x07\n\x0bHealthCheck\x12\x30\n\x07timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\x12\x31\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\x12\x1f\n\x17interval_jitter_percent\x18\x03 \x01(\x01\x12\x19\n\x11healthy_threshold\x18\x04 \x01(\x03\x12\x1b\n\x13unhealthy_threshold\x18\x05 \x01(\x03\x12%\n\x10healthcheck_port\x18\x06 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-65535\x12P\n\x06stream\x18\x07 \x01(\x0b\x32>.yandex.cloud.apploadbalancer.v1.HealthCheck.StreamHealthCheckH\x00\x12L\n\x04http\x18\x08 \x01(\x0b\x32<.yandex.cloud.apploadbalancer.v1.HealthCheck.HttpHealthCheckH\x00\x12L\n\x04grpc\x18\t \x01(\x0b\x32<.yandex.cloud.apploadbalancer.v1.HealthCheck.GrpcHealthCheckH\x00\x12P\n\tplaintext\x18\n \x01(\x0b\x32;.yandex.cloud.apploadbalancer.v1.PlaintextTransportSettingsH\x01\x12G\n\x03tls\x18\x0b \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.SecureTransportSettingsH\x01\x1a\x86\x01\n\x11StreamHealthCheck\x12\x36\n\x04send\x18\x01 \x01(\x0b\x32(.yandex.cloud.apploadbalancer.v1.Payload\x12\x39\n\x07receive\x18\x02 \x01(\x0b\x32(.yandex.cloud.apploadbalancer.v1.Payload\x1ar\n\x0fHttpHealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tuse_http2\x18\x03 \x01(\x08\x12*\n\x11\x65xpected_statuses\x18\x04 \x03(\x03\x42\x0f\xfa\xc7\x31\x07\x31\x30\x30-599\x90\xc8\x31\x01\x1a\'\n\x0fGrpcHealthCheck\x12\x14\n\x0cservice_name\x18\x01 \x01(\tB\x13\n\x0bhealthcheck\x12\x04\xc0\xc1\x31\x01\x42\x14\n\x12transport_settings*T\n\x11LoadBalancingMode\x12\x0f\n\x0bROUND_ROBIN\x10\x00\x12\n\n\x06RANDOM\x10\x01\x12\x11\n\rLEAST_REQUEST\x10\x02\x12\x0f\n\x0bMAGLEV_HASH\x10\x03\x42z\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.apploadbalancer.v1.backend_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer'
  _BACKENDGROUP_LABELSENTRY._options = None
  _BACKENDGROUP_LABELSENTRY._serialized_options = b'8\001'
  _HEADERSESSIONAFFINITY.fields_by_name['header_name']._options = None
  _HEADERSESSIONAFFINITY.fields_by_name['header_name']._serialized_options = b'\212\3101\0051-256'
  _COOKIESESSIONAFFINITY.fields_by_name['name']._options = None
  _COOKIESESSIONAFFINITY.fields_by_name['name']._serialized_options = b'\212\3101\0051-256'
  _LOADBALANCINGCONFIG.fields_by_name['panic_threshold']._options = None
  _LOADBALANCINGCONFIG.fields_by_name['panic_threshold']._serialized_options = b'\372\3071\0050-100'
  _LOADBALANCINGCONFIG.fields_by_name['locality_aware_routing_percent']._options = None
  _LOADBALANCINGCONFIG.fields_by_name['locality_aware_routing_percent']._serialized_options = b'\372\3071\0050-100'
  _STREAMBACKEND.oneofs_by_name['backend_type']._options = None
  _STREAMBACKEND.oneofs_by_name['backend_type']._serialized_options = b'\300\3011\001'
  _STREAMBACKEND.fields_by_name['name']._options = None
  _STREAMBACKEND.fields_by_name['name']._serialized_options = b'\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _STREAMBACKEND.fields_by_name['port']._options = None
  _STREAMBACKEND.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _HTTPBACKEND.oneofs_by_name['backend_type']._options = None
  _HTTPBACKEND.oneofs_by_name['backend_type']._serialized_options = b'\300\3011\001'
  _HTTPBACKEND.fields_by_name['name']._options = None
  _HTTPBACKEND.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _HTTPBACKEND.fields_by_name['port']._options = None
  _HTTPBACKEND.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _GRPCBACKEND.oneofs_by_name['backend_type']._options = None
  _GRPCBACKEND.oneofs_by_name['backend_type']._serialized_options = b'\300\3011\001'
  _GRPCBACKEND.fields_by_name['name']._options = None
  _GRPCBACKEND.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\034[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _GRPCBACKEND.fields_by_name['port']._options = None
  _GRPCBACKEND.fields_by_name['port']._serialized_options = b'\372\3071\0070-65535'
  _TARGETGROUPSBACKEND.fields_by_name['target_group_ids']._options = None
  _TARGETGROUPSBACKEND.fields_by_name['target_group_ids']._serialized_options = b'\202\3101\002>0'
  _STORAGEBUCKETBACKEND.fields_by_name['bucket']._options = None
  _STORAGEBUCKETBACKEND.fields_by_name['bucket']._serialized_options = b'\350\3071\001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._serialized_options = b'\350\3071\001'
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['expected_statuses']._options = None
  _HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['expected_statuses']._serialized_options = b'\372\3071\007100-599\220\3101\001'
  _HEALTHCHECK.oneofs_by_name['healthcheck']._options = None
  _HEALTHCHECK.oneofs_by_name['healthcheck']._serialized_options = b'\300\3011\001'
  _HEALTHCHECK.fields_by_name['timeout']._options = None
  _HEALTHCHECK.fields_by_name['timeout']._serialized_options = b'\350\3071\001'
  _HEALTHCHECK.fields_by_name['interval']._options = None
  _HEALTHCHECK.fields_by_name['interval']._serialized_options = b'\350\3071\001'
  _HEALTHCHECK.fields_by_name['healthcheck_port']._options = None
  _HEALTHCHECK.fields_by_name['healthcheck_port']._serialized_options = b'\372\3071\0070-65535'
  _globals['_LOADBALANCINGMODE']._serialized_start=4950
  _globals['_LOADBALANCINGMODE']._serialized_end=5034
  _globals['_BACKENDGROUP']._serialized_start=307
  _globals['_BACKENDGROUP']._serialized_end=779
  _globals['_BACKENDGROUP_LABELSENTRY']._serialized_start=717
  _globals['_BACKENDGROUP_LABELSENTRY']._serialized_end=762
  _globals['_STREAMBACKENDGROUP']._serialized_start=782
  _globals['_STREAMBACKENDGROUP']._serialized_end=970
  _globals['_HTTPBACKENDGROUP']._serialized_start=973
  _globals['_HTTPBACKENDGROUP']._serialized_end=1305
  _globals['_GRPCBACKENDGROUP']._serialized_start=1308
  _globals['_GRPCBACKENDGROUP']._serialized_end=1640
  _globals['_HEADERSESSIONAFFINITY']._serialized_start=1642
  _globals['_HEADERSESSIONAFFINITY']._serialized_end=1697
  _globals['_COOKIESESSIONAFFINITY']._serialized_start=1699
  _globals['_COOKIESESSIONAFFINITY']._serialized_end=1787
  _globals['_CONNECTIONSESSIONAFFINITY']._serialized_start=1789
  _globals['_CONNECTIONSESSIONAFFINITY']._serialized_end=1835
  _globals['_LOADBALANCINGCONFIG']._serialized_start=1838
  _globals['_LOADBALANCINGCONFIG']._serialized_end=2037
  _globals['_STREAMBACKEND']._serialized_start=2040
  _globals['_STREAMBACKEND']._serialized_end=2575
  _globals['_HTTPBACKEND']._serialized_start=2578
  _globals['_HTTPBACKEND']._serialized_end=3135
  _globals['_GRPCBACKEND']._serialized_start=3138
  _globals['_GRPCBACKEND']._serialized_end=3601
  _globals['_TARGETGROUPSBACKEND']._serialized_start=3603
  _globals['_TARGETGROUPSBACKEND']._serialized_end=3658
  _globals['_PLAINTEXTTRANSPORTSETTINGS']._serialized_start=3660
  _globals['_PLAINTEXTTRANSPORTSETTINGS']._serialized_end=3688
  _globals['_SECURETRANSPORTSETTINGS']._serialized_start=3690
  _globals['_SECURETRANSPORTSETTINGS']._serialized_end=3814
  _globals['_BACKENDTLS']._serialized_start=3816
  _globals['_BACKENDTLS']._serialized_end=3927
  _globals['_STORAGEBUCKETBACKEND']._serialized_start=3929
  _globals['_STORAGEBUCKETBACKEND']._serialized_end=3973
  _globals['_HEALTHCHECK']._serialized_start=3976
  _globals['_HEALTHCHECK']._serialized_end=4948
  _globals['_HEALTHCHECK_STREAMHEALTHCHECK']._serialized_start=4614
  _globals['_HEALTHCHECK_STREAMHEALTHCHECK']._serialized_end=4748
  _globals['_HEALTHCHECK_HTTPHEALTHCHECK']._serialized_start=4750
  _globals['_HEALTHCHECK_HTTPHEALTHCHECK']._serialized_end=4864
  _globals['_HEALTHCHECK_GRPCHEALTHCHECK']._serialized_start=4866
  _globals['_HEALTHCHECK_GRPCHEALTHCHECK']._serialized_end=4905
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/video/v1/playlist_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import playlist_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_playlist__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/video/v1/playlist_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a$yandex/cloud/video/v1/playlist.proto\"7\n\x12GetPlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xaa\x01\n\x14ListPlaylistsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x64 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x65 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"j\n\x15ListPlaylistsResponse\x12\x32\n\tplaylists\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.video.v1.Playlist\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xa2\x01\n\x15\x43reatePlaylistRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x05title\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12=\n\x05items\x18\x04 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItemB\t\x82\xc8\x31\x05<=100\"-\n\x16\x43reatePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\"\xcd\x01\n\x15UpdatePlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12=\n\x05items\x18\x05 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItemB\t\x82\xc8\x31\x05<=100\"-\n\x16UpdatePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\":\n\x15\x44\x65letePlaylistRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65letePlaylistMetadata\x12\x13\n\x0bplaylist_id\x18\x01 \x01(\t\"h\n\x1b\x42\x61tchDeletePlaylistsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\'\n\x0cplaylist_ids\x18\x02 \x03(\tB\x11\x82\xc8\x31\x05\x31-100\x8a\xc8\x31\x04<=50\"4\n\x1c\x42\x61tchDeletePlaylistsMetadata\x12\x14\n\x0cplaylist_ids\x18\x01 \x03(\t\"}\n\x1bGetPlaylistPlayerURLRequest\x12!\n\x0bplaylist_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12;\n\x06params\x18\x02 \x01(\x0b\x32+.yandex.cloud.video.v1.PlaylistPlayerParams\"F\n\x14PlaylistPlayerParams\x12\x0c\n\x04mute\x18\x01 \x01(\x08\x12\x10\n\x08\x61utoplay\x18\x02 \x01(\x08\x12\x0e\n\x06hidden\x18\x03 \x01(\x08\"@\n\x1cGetPlaylistPlayerURLResponse\x12\x12\n\nplayer_url\x18\x01 \x01(\t\x12\x0c\n\x04html\x18\x02 \x01(\t2\x99\t\n\x0fPlaylistService\x12|\n\x03Get\x12).yandex.cloud.video.v1.GetPlaylistRequest\x1a\x1f.yandex.cloud.video.v1.Playlist\")\x82\xd3\xe4\x93\x02#\x12!/video/v1/playlists/{playlist_id}\x12~\n\x04List\x12+.yandex.cloud.video.v1.ListPlaylistsRequest\x1a,.yandex.cloud.video.v1.ListPlaylistsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/video/v1/playlists\x12\x9f\x01\n\x06\x43reate\x12,.yandex.cloud.video.v1.CreatePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\"\n\x16\x43reatePlaylistMetadata\x12\x08Playlist\x82\xd3\xe4\x93\x02\x18\"\x13/video/v1/playlists:\x01*\x12\xad\x01\n\x06Update\x12,.yandex.cloud.video.v1.UpdatePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*\"\n\x16UpdatePlaylistMetadata\x12\x08Playlist\x82\xd3\xe4\x93\x02&2!/video/v1/playlists/{playlist_id}:\x01*\x12\xb7\x01\n\x06\x44\x65lete\x12,.yandex.cloud.video.v1.DeletePlaylistRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*/\n\x16\x44\x65letePlaylistMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02#*!/video/v1/playlists/{playlist_id}\x12\xc9\x01\n\x0b\x42\x61tchDelete\x12\x32.yandex.cloud.video.v1.BatchDeletePlaylistsRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*5\n\x1c\x42\x61tchDeletePlaylistsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$\"\x1f/video/v1/playlists:batchDelete:\x01*\x12\xaf\x01\n\x0cGetPlayerURL\x12\x32.yandex.cloud.video.v1.GetPlaylistPlayerURLRequest\x1a\x33.yandex.cloud.video.v1.GetPlaylistPlayerURLResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./video/v1/playlists/{playlist_id}:getPlayerURLB\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.playlist_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _GETPLAYLISTREQUEST.fields_by_name['playlist_id']._options = None
  _GETPLAYLISTREQUEST.fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPLAYLISTSREQUEST.fields_by_name['channel_id']._options = None
  _LISTPLAYLISTSREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTPLAYLISTSREQUEST.fields_by_name['page_size']._options = None
  _LISTPLAYLISTSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTPLAYLISTSREQUEST.fields_by_name['page_token']._options = None
  _LISTPLAYLISTSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=200'
  _LISTPLAYLISTSREQUEST.fields_by_name['filter']._options = None
  _LISTPLAYLISTSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATEPLAYLISTREQUEST.fields_by_name['channel_id']._options = None
  _CREATEPLAYLISTREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPLAYLISTREQUEST.fields_by_name['title']._options = None
  _CREATEPLAYLISTREQUEST.fields_by_name['title']._serialized_options = b'\350\3071\001'
  _CREATEPLAYLISTREQUEST.fields_by_name['items']._options = None
  _CREATEPLAYLISTREQUEST.fields_by_name['items']._serialized_options = b'\202\3101\005<=100'
  _UPDATEPLAYLISTREQUEST.fields_by_name['playlist_id']._options = None
  _UPDATEPLAYLISTREQUEST.fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPLAYLISTREQUEST.fields_by_name['items']._options = None
  _UPDATEPLAYLISTREQUEST.fields_by_name['items']._serialized_options = b'\202\3101\005<=100'
  _DELETEPLAYLISTREQUEST.fields_by_name['playlist_id']._options = None
  _DELETEPLAYLISTREQUEST.fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHDELETEPLAYLISTSREQUEST.fields_by_name['channel_id']._options = None
  _BATCHDELETEPLAYLISTSREQUEST.fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHDELETEPLAYLISTSREQUEST.fields_by_name['playlist_ids']._options = None
  _BATCHDELETEPLAYLISTSREQUEST.fields_by_name['playlist_ids']._serialized_options = b'\202\3101\0051-100\212\3101\004<=50'
  _GETPLAYLISTPLAYERURLREQUEST.fields_by_name['playlist_id']._options = None
  _GETPLAYLISTPLAYERURLREQUEST.fields_by_name['playlist_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _PLAYLISTSERVICE.methods_by_name['Get']._options = None
  _PLAYLISTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002#\022!/video/v1/playlists/{playlist_id}'
  _PLAYLISTSERVICE.methods_by_name['List']._options = None
  _PLAYLISTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/video/v1/playlists'
  _PLAYLISTSERVICE.methods_by_name['Create']._options = None
  _PLAYLISTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreatePlaylistMetadata\022\010Playlist\202\323\344\223\002\030\"\023/video/v1/playlists:\001*'
  _PLAYLISTSERVICE.methods_by_name['Update']._options = None
  _PLAYLISTSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdatePlaylistMetadata\022\010Playlist\202\323\344\223\002&2!/video/v1/playlists/{playlist_id}:\001*'
  _PLAYLISTSERVICE.methods_by_name['Delete']._options = None
  _PLAYLISTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeletePlaylistMetadata\022\025google.protobuf.Empty\202\323\344\223\002#*!/video/v1/playlists/{playlist_id}'
  _PLAYLISTSERVICE.methods_by_name['BatchDelete']._options = None
  _PLAYLISTSERVICE.methods_by_name['BatchDelete']._serialized_options = b'\262\322*5\n\034BatchDeletePlaylistsMetadata\022\025google.protobuf.Empty\202\323\344\223\002$\"\037/video/v1/playlists:batchDelete:\001*'
  _PLAYLISTSERVICE.methods_by_name['GetPlayerURL']._options = None
  _PLAYLISTSERVICE.methods_by_name['GetPlayerURL']._serialized_options = b'\202\323\344\223\0020\022./video/v1/playlists/{playlist_id}:getPlayerURL'
  _globals['_GETPLAYLISTREQUEST']._serialized_start=278
  _globals['_GETPLAYLISTREQUEST']._serialized_end=333
  _globals['_LISTPLAYLISTSREQUEST']._serialized_start=336
  _globals['_LISTPLAYLISTSREQUEST']._serialized_end=506
  _globals['_LISTPLAYLISTSRESPONSE']._serialized_start=508
  _globals['_LISTPLAYLISTSRESPONSE']._serialized_end=614
  _globals['_CREATEPLAYLISTREQUEST']._serialized_start=617
  _globals['_CREATEPLAYLISTREQUEST']._serialized_end=779
  _globals['_CREATEPLAYLISTMETADATA']._serialized_start=781
  _globals['_CREATEPLAYLISTMETADATA']._serialized_end=826
  _globals['_UPDATEPLAYLISTREQUEST']._serialized_start=829
  _globals['_UPDATEPLAYLISTREQUEST']._serialized_end=1034
  _globals['_UPDATEPLAYLISTMETADATA']._serialized_start=1036
  _globals['_UPDATEPLAYLISTMETADATA']._serialized_end=1081
  _globals['_DELETEPLAYLISTREQUEST']._serialized_start=1083
  _globals['_DELETEPLAYLISTREQUEST']._serialized_end=1141
  _globals['_DELETEPLAYLISTMETADATA']._serialized_start=1143
  _globals['_DELETEPLAYLISTMETADATA']._serialized_end=1188
  _globals['_BATCHDELETEPLAYLISTSREQUEST']._serialized_start=1190
  _globals['_BATCHDELETEPLAYLISTSREQUEST']._serialized_end=1294
  _globals['_BATCHDELETEPLAYLISTSMETADATA']._serialized_start=1296
  _globals['_BATCHDELETEPLAYLISTSMETADATA']._serialized_end=1348
  _globals['_GETPLAYLISTPLAYERURLREQUEST']._serialized_start=1350
  _globals['_GETPLAYLISTPLAYERURLREQUEST']._serialized_end=1475
  _globals['_PLAYLISTPLAYERPARAMS']._serialized_start=1477
  _globals['_PLAYLISTPLAYERPARAMS']._serialized_end=1547
  _globals['_GETPLAYLISTPLAYERURLRESPONSE']._serialized_start=1549
  _globals['_GETPLAYLISTPLAYERURLRESPONSE']._serialized_end=1613
  _globals['_PLAYLISTSERVICE']._serialized_start=1616
  _globals['_PLAYLISTSERVICE']._serialized_end=2793
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/test/status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/loadtesting/api/v1/test/status.proto\x12$yandex.cloud.loadtesting.api.v1.test*\xe3\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\r\n\tINITIATED\x10\x02\x12\r\n\tPREPARING\x10\x03\x12\x0b\n\x07RUNNING\x10\x04\x12\r\n\tFINISHING\x10\x05\x12\x08\n\x04\x44ONE\x10\x06\x12\x13\n\x0fPOST_PROCESSING\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\x0c\n\x08STOPPING\x10\t\x12\x0b\n\x07STOPPED\x10\n\x12\x0f\n\x0b\x41UTOSTOPPED\x10\x0b\x12\x0b\n\x07WAITING\x10\x0c\x12\x0c\n\x08\x44\x45LETING\x10\r\x12\x08\n\x04LOST\x10\x0e\x42y\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _globals['_STATUS']._serialized_start=92
  _globals['_STATUS']._serialized_end=319
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.searchapi.v2.search_query_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SortSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SortOrder:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SortOrderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SortSpec._SortOrder.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SORT_ORDER_UNSPECIFIED: SortSpec._SortOrder.ValueType  # 0
        SORT_ORDER_ASC: SortSpec._SortOrder.ValueType  # 1
        """Reverse order from oldest to most recent."""
        SORT_ORDER_DESC: SortSpec._SortOrder.ValueType  # 2
        """Direct order from most recent to oldest (default)."""

    class SortOrder(_SortOrder, metaclass=_SortOrderEnumTypeWrapper): ...
    SORT_ORDER_UNSPECIFIED: SortSpec.SortOrder.ValueType  # 0
    SORT_ORDER_ASC: SortSpec.SortOrder.ValueType  # 1
    """Reverse order from oldest to most recent."""
    SORT_ORDER_DESC: SortSpec.SortOrder.ValueType  # 2
    """Direct order from most recent to oldest (default)."""

    class _SortMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SortModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SortSpec._SortMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SORT_MODE_UNSPECIFIED: SortSpec._SortMode.ValueType  # 0
        SORT_MODE_BY_RELEVANCE: SortSpec._SortMode.ValueType  # 1
        """Sort documents by relevance (default value)."""
        SORT_MODE_BY_TIME: SortSpec._SortMode.ValueType  # 2
        """Sort documents by update time."""

    class SortMode(_SortMode, metaclass=_SortModeEnumTypeWrapper): ...
    SORT_MODE_UNSPECIFIED: SortSpec.SortMode.ValueType  # 0
    SORT_MODE_BY_RELEVANCE: SortSpec.SortMode.ValueType  # 1
    """Sort documents by relevance (default value)."""
    SORT_MODE_BY_TIME: SortSpec.SortMode.ValueType  # 2
    """Sort documents by update time."""

    SORT_MODE_FIELD_NUMBER: builtins.int
    SORT_ORDER_FIELD_NUMBER: builtins.int
    sort_mode: global___SortSpec.SortMode.ValueType
    """Documents sorting mode."""
    sort_order: global___SortSpec.SortOrder.ValueType
    """Documents sorting order."""
    def __init__(
        self,
        *,
        sort_mode: global___SortSpec.SortMode.ValueType = ...,
        sort_order: global___SortSpec.SortOrder.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sort_mode", b"sort_mode", "sort_order", b"sort_order"]) -> None: ...

global___SortSpec = SortSpec

@typing.final
class GroupSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _GroupMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _GroupModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GroupSpec._GroupMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        GROUP_MODE_UNSPECIFIED: GroupSpec._GroupMode.ValueType  # 0
        GROUP_MODE_FLAT: GroupSpec._GroupMode.ValueType  # 1
        """Flat grouping. Each group contains a single document."""
        GROUP_MODE_DEEP: GroupSpec._GroupMode.ValueType  # 2
        """Grouping by domain. Each group contains documents from one domain."""

    class GroupMode(_GroupMode, metaclass=_GroupModeEnumTypeWrapper): ...
    GROUP_MODE_UNSPECIFIED: GroupSpec.GroupMode.ValueType  # 0
    GROUP_MODE_FLAT: GroupSpec.GroupMode.ValueType  # 1
    """Flat grouping. Each group contains a single document."""
    GROUP_MODE_DEEP: GroupSpec.GroupMode.ValueType  # 2
    """Grouping by domain. Each group contains documents from one domain."""

    GROUP_MODE_FIELD_NUMBER: builtins.int
    GROUPS_ON_PAGE_FIELD_NUMBER: builtins.int
    DOCS_IN_GROUP_FIELD_NUMBER: builtins.int
    group_mode: global___GroupSpec.GroupMode.ValueType
    """Grouping method."""
    groups_on_page: builtins.int
    """Maximum number of groups that can be returned per page with search results."""
    docs_in_group: builtins.int
    """Maximum number of documents that can be returned per group."""
    def __init__(
        self,
        *,
        group_mode: global___GroupSpec.GroupMode.ValueType = ...,
        groups_on_page: builtins.int = ...,
        docs_in_group: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["docs_in_group", b"docs_in_group", "group_mode", b"group_mode", "groups_on_page", b"groups_on_page"]) -> None: ...

global___GroupSpec = GroupSpec

@typing.final
class WebSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Localization:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LocalizationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WebSearchRequest._Localization.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LOCALIZATION_UNSPECIFIED: WebSearchRequest._Localization.ValueType  # 0
        LOCALIZATION_RU: WebSearchRequest._Localization.ValueType  # 1
        """Russian (default value)"""
        LOCALIZATION_UK: WebSearchRequest._Localization.ValueType  # 2
        """Ukrainian"""
        LOCALIZATION_BE: WebSearchRequest._Localization.ValueType  # 3
        """Belarusian"""
        LOCALIZATION_KK: WebSearchRequest._Localization.ValueType  # 4
        """Kazakh"""
        LOCALIZATION_TR: WebSearchRequest._Localization.ValueType  # 5
        """Turkish"""
        LOCALIZATION_EN: WebSearchRequest._Localization.ValueType  # 6
        """English"""

    class Localization(_Localization, metaclass=_LocalizationEnumTypeWrapper): ...
    LOCALIZATION_UNSPECIFIED: WebSearchRequest.Localization.ValueType  # 0
    LOCALIZATION_RU: WebSearchRequest.Localization.ValueType  # 1
    """Russian (default value)"""
    LOCALIZATION_UK: WebSearchRequest.Localization.ValueType  # 2
    """Ukrainian"""
    LOCALIZATION_BE: WebSearchRequest.Localization.ValueType  # 3
    """Belarusian"""
    LOCALIZATION_KK: WebSearchRequest.Localization.ValueType  # 4
    """Kazakh"""
    LOCALIZATION_TR: WebSearchRequest.Localization.ValueType  # 5
    """Turkish"""
    LOCALIZATION_EN: WebSearchRequest.Localization.ValueType  # 6
    """English"""

    class _Format:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WebSearchRequest._Format.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FORMAT_UNSPECIFIED: WebSearchRequest._Format.ValueType  # 0
        FORMAT_XML: WebSearchRequest._Format.ValueType  # 1
        """XML format (default value)"""
        FORMAT_HTML: WebSearchRequest._Format.ValueType  # 2
        """HTML format"""

    class Format(_Format, metaclass=_FormatEnumTypeWrapper): ...
    FORMAT_UNSPECIFIED: WebSearchRequest.Format.ValueType  # 0
    FORMAT_XML: WebSearchRequest.Format.ValueType  # 1
    """XML format (default value)"""
    FORMAT_HTML: WebSearchRequest.Format.ValueType  # 2
    """HTML format"""

    QUERY_FIELD_NUMBER: builtins.int
    SORT_SPEC_FIELD_NUMBER: builtins.int
    GROUP_SPEC_FIELD_NUMBER: builtins.int
    MAX_PASSAGES_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    L10N_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    RESPONSE_FORMAT_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    max_passages: builtins.int
    """The maximum number of passages that can be used when generating a document snippet."""
    region: builtins.str
    """ID of the search country or region that impacts the document ranking rules."""
    l10n: global___WebSearchRequest.Localization.ValueType
    """The notification language for a search response."""
    folder_id: builtins.str
    """ID of the folder."""
    response_format: global___WebSearchRequest.Format.ValueType
    """Search results format."""
    user_agent: builtins.str
    """User-Agent request header value."""
    @property
    def query(self) -> yandex.cloud.searchapi.v2.search_query_pb2.SearchQuery:
        """Search query."""

    @property
    def sort_spec(self) -> global___SortSpec:
        """The rules for sorting search results that define the sequence of the returned search results."""

    @property
    def group_spec(self) -> global___GroupSpec:
        """Grouping settings that are used to group documents from a single domain into a container."""

    def __init__(
        self,
        *,
        query: yandex.cloud.searchapi.v2.search_query_pb2.SearchQuery | None = ...,
        sort_spec: global___SortSpec | None = ...,
        group_spec: global___GroupSpec | None = ...,
        max_passages: builtins.int = ...,
        region: builtins.str = ...,
        l10n: global___WebSearchRequest.Localization.ValueType = ...,
        folder_id: builtins.str = ...,
        response_format: global___WebSearchRequest.Format.ValueType = ...,
        user_agent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group_spec", b"group_spec", "query", b"query", "sort_spec", b"sort_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "group_spec", b"group_spec", "l10n", b"l10n", "max_passages", b"max_passages", "query", b"query", "region", b"region", "response_format", b"response_format", "sort_spec", b"sort_spec", "user_agent", b"user_agent"]) -> None: ...

global___WebSearchRequest = WebSearchRequest

@typing.final
class WebSearchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_DATA_FIELD_NUMBER: builtins.int
    raw_data: builtins.bytes
    """Search results, either in XML or HTML format depending on the request settings."""
    def __init__(
        self,
        *,
        raw_data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["raw_data", b"raw_data"]) -> None: ...

global___WebSearchResponse = WebSearchResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.thumbnail_pb2
import yandex.cloud.video.v1.thumbnail_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ThumbnailServiceStub:
    """Thumbnail management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.GetThumbnailRequest,
        yandex.cloud.video.v1.thumbnail_pb2.Thumbnail,
    ]
    """Returns the specific thumbnail."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.ListThumbnailRequest,
        yandex.cloud.video.v1.thumbnail_service_pb2.ListThumbnailResponse,
    ]
    """List thumbnails for channel."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.CreateThumbnailRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create thumbnail."""

    BatchGenerateDownloadURLs: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.BatchGenerateDownloadURLsRequest,
        yandex.cloud.video.v1.thumbnail_service_pb2.BatchGenerateDownloadURLsResponse,
    ]
    """Generate urls for download images."""

    GenerateUploadURL: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.GenerateThumbnailUploadURLRequest,
        yandex.cloud.video.v1.thumbnail_service_pb2.GenerateThumbnailUploadURLResponse,
    ]
    """Generate url for upload image."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.DeleteThumbnailRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete thumbnail."""

class ThumbnailServiceAsyncStub:
    """Thumbnail management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.GetThumbnailRequest,
        yandex.cloud.video.v1.thumbnail_pb2.Thumbnail,
    ]
    """Returns the specific thumbnail."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.ListThumbnailRequest,
        yandex.cloud.video.v1.thumbnail_service_pb2.ListThumbnailResponse,
    ]
    """List thumbnails for channel."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.CreateThumbnailRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create thumbnail."""

    BatchGenerateDownloadURLs: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.BatchGenerateDownloadURLsRequest,
        yandex.cloud.video.v1.thumbnail_service_pb2.BatchGenerateDownloadURLsResponse,
    ]
    """Generate urls for download images."""

    GenerateUploadURL: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.GenerateThumbnailUploadURLRequest,
        yandex.cloud.video.v1.thumbnail_service_pb2.GenerateThumbnailUploadURLResponse,
    ]
    """Generate url for upload image."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.thumbnail_service_pb2.DeleteThumbnailRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete thumbnail."""

class ThumbnailServiceServicer(metaclass=abc.ABCMeta):
    """Thumbnail management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.thumbnail_service_pb2.GetThumbnailRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.thumbnail_pb2.Thumbnail, collections.abc.Awaitable[yandex.cloud.video.v1.thumbnail_pb2.Thumbnail]]:
        """Returns the specific thumbnail."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.thumbnail_service_pb2.ListThumbnailRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.thumbnail_service_pb2.ListThumbnailResponse, collections.abc.Awaitable[yandex.cloud.video.v1.thumbnail_service_pb2.ListThumbnailResponse]]:
        """List thumbnails for channel."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.thumbnail_service_pb2.CreateThumbnailRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create thumbnail."""

    @abc.abstractmethod
    def BatchGenerateDownloadURLs(
        self,
        request: yandex.cloud.video.v1.thumbnail_service_pb2.BatchGenerateDownloadURLsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.thumbnail_service_pb2.BatchGenerateDownloadURLsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.thumbnail_service_pb2.BatchGenerateDownloadURLsResponse]]:
        """Generate urls for download images."""

    @abc.abstractmethod
    def GenerateUploadURL(
        self,
        request: yandex.cloud.video.v1.thumbnail_service_pb2.GenerateThumbnailUploadURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.thumbnail_service_pb2.GenerateThumbnailUploadURLResponse, collections.abc.Awaitable[yandex.cloud.video.v1.thumbnail_service_pb2.GenerateThumbnailUploadURLResponse]]:
        """Generate url for upload image."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.thumbnail_service_pb2.DeleteThumbnailRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete thumbnail."""

def add_ThumbnailServiceServicer_to_server(servicer: ThumbnailServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.datatransfer.v1 import endpoint_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/datatransfer/v1/endpoint_service.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a+yandex/cloud/datatransfer/v1/endpoint.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\")\n\x12GetEndpointRequest\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t\"P\n\x14ListEndpointsRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"k\n\x15ListEndpointsResponse\x12\x39\n\tendpoints\x18\x01 \x03(\x0b\x32&.yandex.cloud.datatransfer.v1.Endpoint\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x95\x02\n\x15\x43reateEndpointRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12O\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.datatransfer.v1.CreateEndpointRequest.LabelsEntry\x12@\n\x08settings\x18\x34 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.EndpointSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x34\"-\n\x16\x43reateEndpointMetadata\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t\"\xd4\x02\n\x15UpdateEndpointRequest\x12\x13\n\x0b\x65ndpoint_id\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12O\n\x06labels\x18\r \x03(\x0b\x32?.yandex.cloud.datatransfer.v1.UpdateEndpointRequest.LabelsEntry\x12@\n\x08settings\x18\x34 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.EndpointSettings\x12/\n\x0bupdate_mask\x18< \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x01\x10\nJ\x04\x08\x0e\x10\x34J\x04\x08\x35\x10<\"-\n\x16UpdateEndpointMetadata\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t\",\n\x15\x44\x65leteEndpointRequest\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t\"-\n\x16\x44\x65leteEndpointMetadata\x12\x13\n\x0b\x65ndpoint_id\x18\x01 \x01(\t2\xbd\x06\n\x0f\x45ndpointService\x12\x83\x01\n\x03Get\x12\x30.yandex.cloud.datatransfer.v1.GetEndpointRequest\x1a&.yandex.cloud.datatransfer.v1.Endpoint\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/endpoint/{endpoint_id}\x12\x97\x01\n\x04List\x12\x32.yandex.cloud.datatransfer.v1.ListEndpointsRequest\x1a\x33.yandex.cloud.datatransfer.v1.ListEndpointsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/endpoints/list/{folder_id}\x12\x9f\x01\n\x06\x43reate\x12\x33.yandex.cloud.datatransfer.v1.CreateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"=\xb2\xd2*\"\n\x16\x43reateEndpointMetadata\x12\x08\x45ndpoint\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/endpoint:\x01*\x12\xad\x01\n\x06Update\x12\x33.yandex.cloud.datatransfer.v1.UpdateEndpointRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*\"\n\x16UpdateEndpointMetadata\x12\x08\x45ndpoint\x82\xd3\xe4\x93\x02\x1f\x32\x1a/v1/endpoint/{endpoint_id}:\x01*\x12\xb7\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.datatransfer.v1.DeleteEndpointRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*/\n\x16\x44\x65leteEndpointMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/endpoint/{endpoint_id}Bq\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer'
  _CREATEENDPOINTREQUEST_LABELSENTRY._options = None
  _CREATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEENDPOINTREQUEST_LABELSENTRY._options = None
  _UPDATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ENDPOINTSERVICE.methods_by_name['Get']._options = None
  _ENDPOINTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/endpoint/{endpoint_id}'
  _ENDPOINTSERVICE.methods_by_name['List']._options = None
  _ENDPOINTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002 \022\036/v1/endpoints/list/{folder_id}'
  _ENDPOINTSERVICE.methods_by_name['Create']._options = None
  _ENDPOINTSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateEndpointMetadata\022\010Endpoint\202\323\344\223\002\021\"\014/v1/endpoint:\001*'
  _ENDPOINTSERVICE.methods_by_name['Update']._options = None
  _ENDPOINTSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateEndpointMetadata\022\010Endpoint\202\323\344\223\002\0372\032/v1/endpoint/{endpoint_id}:\001*'
  _ENDPOINTSERVICE.methods_by_name['Delete']._options = None
  _ENDPOINTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteEndpointMetadata\022\025google.protobuf.Empty\202\323\344\223\002\034*\032/v1/endpoint/{endpoint_id}'
  _globals['_GETENDPOINTREQUEST']._serialized_start=268
  _globals['_GETENDPOINTREQUEST']._serialized_end=309
  _globals['_LISTENDPOINTSREQUEST']._serialized_start=311
  _globals['_LISTENDPOINTSREQUEST']._serialized_end=391
  _globals['_LISTENDPOINTSRESPONSE']._serialized_start=393
  _globals['_LISTENDPOINTSRESPONSE']._serialized_end=500
  _globals['_CREATEENDPOINTREQUEST']._serialized_start=503
  _globals['_CREATEENDPOINTREQUEST']._serialized_end=780
  _globals['_CREATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=729
  _globals['_CREATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=774
  _globals['_CREATEENDPOINTMETADATA']._serialized_start=782
  _globals['_CREATEENDPOINTMETADATA']._serialized_end=827
  _globals['_UPDATEENDPOINTREQUEST']._serialized_start=830
  _globals['_UPDATEENDPOINTREQUEST']._serialized_end=1170
  _globals['_UPDATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=729
  _globals['_UPDATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=774
  _globals['_UPDATEENDPOINTMETADATA']._serialized_start=1172
  _globals['_UPDATEENDPOINTMETADATA']._serialized_end=1217
  _globals['_DELETEENDPOINTREQUEST']._serialized_start=1219
  _globals['_DELETEENDPOINTREQUEST']._serialized_end=1263
  _globals['_DELETEENDPOINTMETADATA']._serialized_start=1265
  _globals['_DELETEENDPOINTMETADATA']._serialized_end=1310
  _globals['_ENDPOINTSERVICE']._serialized_start=1313
  _globals['_ENDPOINTSERVICE']._serialized_end=2142
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cloudregistry/v1/artifact_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.cloudregistry.v1 import artifact_pb2 as yandex_dot_cloud_dot_cloudregistry_dot_v1_dot_artifact__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/cloudregistry/v1/artifact_service.proto\x12\x1dyandex.cloud.cloudregistry.v1\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/cloudregistry/v1/artifact.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1cgoogle/api/annotations.proto\"7\n\x12GetArtifactRequest\x12!\n\x0b\x61rtifact_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\":\n\x15\x44\x65leteArtifactRequest\x12!\n\x0b\x61rtifact_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteArtifactMetadata\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\t2\xf4\x02\n\x0f\x41rtifactService\x12\x95\x01\n\x03Get\x12\x31.yandex.cloud.cloudregistry.v1.GetArtifactRequest\x1a\'.yandex.cloud.cloudregistry.v1.Artifact\"2\x82\xd3\xe4\x93\x02,\x12*/cloud-registry/v1/artifacts/{artifact_id}\x12\xc8\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.cloudregistry.v1.DeleteArtifactRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*/\n\x16\x44\x65leteArtifactMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02,**/cloud-registry/v1/artifacts/{artifact_id}Bt\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudregistry.v1.artifact_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistry'
  _GETARTIFACTREQUEST.fields_by_name['artifact_id']._options = None
  _GETARTIFACTREQUEST.fields_by_name['artifact_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEARTIFACTREQUEST.fields_by_name['artifact_id']._options = None
  _DELETEARTIFACTREQUEST.fields_by_name['artifact_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ARTIFACTSERVICE.methods_by_name['Get']._options = None
  _ARTIFACTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002,\022*/cloud-registry/v1/artifacts/{artifact_id}'
  _ARTIFACTSERVICE.methods_by_name['Delete']._options = None
  _ARTIFACTSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteArtifactMetadata\022\025google.protobuf.Empty\202\323\344\223\002,**/cloud-registry/v1/artifacts/{artifact_id}'
  _globals['_GETARTIFACTREQUEST']._serialized_start=268
  _globals['_GETARTIFACTREQUEST']._serialized_end=323
  _globals['_DELETEARTIFACTREQUEST']._serialized_start=325
  _globals['_DELETEARTIFACTREQUEST']._serialized_end=383
  _globals['_DELETEARTIFACTMETADATA']._serialized_start=385
  _globals['_DELETEARTIFACTMETADATA']._serialized_end=430
  _globals['_ARTIFACTSERVICE']._serialized_start=433
  _globals['_ARTIFACTSERVICE']._serialized_end=805
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.loadtesting.api.v1.report_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ReportServiceStub:
    """A set of methods for managing test reports."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetTable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportRequest,
        yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportResponse,
    ]
    """Returns a report table for the specified test."""

    CalculateKpiValues: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesRequest,
        yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesResponse,
    ]
    """Returns a list of KPI values for tests matching the specified filter."""

class ReportServiceAsyncStub:
    """A set of methods for managing test reports."""

    GetTable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportRequest,
        yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportResponse,
    ]
    """Returns a report table for the specified test."""

    CalculateKpiValues: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesRequest,
        yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesResponse,
    ]
    """Returns a list of KPI values for tests matching the specified filter."""

class ReportServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing test reports."""

    @abc.abstractmethod
    def GetTable(
        self,
        request: yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.report_service_pb2.GetTableReportResponse]]:
        """Returns a report table for the specified test."""

    @abc.abstractmethod
    def CalculateKpiValues(
        self,
        request: yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesResponse, collections.abc.Awaitable[yandex.cloud.loadtesting.api.v1.report_service_pb2.CalculateReportKpiValuesResponse]]:
        """Returns a list of KPI values for tests matching the specified filter."""

def add_ReportServiceServicer_to_server(servicer: ReportServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



from yandexcloud._backoff import backoff_exponential_jittered_min_interval


def test_backoff_exponential_jittered_min_interval():
    backoff_function = backoff_exponential_jittered_min_interval()
    assert backoff_function(attempt=12) == 60
    for _ in range(100):
        assert 0.025 <= backoff_function(attempt=0) <= 0.075
        assert 51.2 <= backoff_function(attempt=11) <= 60



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Gateway(google.protobuf.message.Message):
    """A Gateway resource. For more information, see [Gateway](/docs/vpc/concepts/gateways)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SHARED_EGRESS_GATEWAY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the gateway. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the gateway belongs to."""
    name: builtins.str
    """Name of the gateway.
    The name is unique within the folder.
    Value must match the regular expression ``\\|[a-z]([-a-z0-9]{0,61}[a-z0-9])?``.
    """
    description: builtins.str
    """Description of the gateway. 0-256 characters long."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Gateway labels as `key:value` pairs. 
        No more than 64 per resource. 
        The maximum string length in characters for each value is 63. 
        Each value must match the regular expression `[-_./\\\\@0-9a-z]*`. 
        The string length in characters for each key must be 1-63. 
        Each key must match the regular expression `[a-z][-_./\\\\@0-9a-z]*`.
        """

    @property
    def shared_egress_gateway(self) -> global___SharedEgressGateway: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        shared_egress_gateway: global___SharedEgressGateway | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "gateway", b"gateway", "shared_egress_gateway", b"shared_egress_gateway"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "gateway", b"gateway", "id", b"id", "labels", b"labels", "name", b"name", "shared_egress_gateway", b"shared_egress_gateway"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["gateway", b"gateway"]) -> typing.Literal["shared_egress_gateway"] | None: ...

global___Gateway = Gateway

@typing.final
class SharedEgressGateway(google.protobuf.message.Message):
    """Shared Egress Gateway configuration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SharedEgressGateway = SharedEgressGateway



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.regression.dashboard_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateRegressionDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a regression dashboard in."""
    name: builtins.str
    """Name of the dashboard."""
    description: builtins.str
    """Description of the dashboard."""
    @property
    def content(self) -> yandex.cloud.loadtesting.api.v1.regression.dashboard_pb2.Dashboard.Content:
        """Content of the dashboard."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        content: yandex.cloud.loadtesting.api.v1.regression.dashboard_pb2.Dashboard.Content | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "description", b"description", "folder_id", b"folder_id", "name", b"name"]) -> None: ...

global___CreateRegressionDashboardRequest = CreateRegressionDashboardRequest

@typing.final
class CreateRegressionDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """ID of the dashboard that is being created."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___CreateRegressionDashboardMetadata = CreateRegressionDashboardMetadata

@typing.final
class GetRegressionDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """ID of the dashboard to return."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___GetRegressionDashboardRequest = GetRegressionDashboardRequest

@typing.final
class DeleteRegressionDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """ID of the dashboard to delete."""
    etag: builtins.str
    """The current etag of the dashboard."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
        etag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id", "etag", b"etag"]) -> None: ...

global___DeleteRegressionDashboardRequest = DeleteRegressionDashboardRequest

@typing.final
class DeleteRegressionDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """ID of the dashboard that is being deleted."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___DeleteRegressionDashboardMetadata = DeleteRegressionDashboardMetadata

@typing.final
class ListRegressionDashboardsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list dashboards in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListRegressionDashboardsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the 
    [ListRegressionDashboardsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters dashboards listed in the response.

    The filter expression may contain multiple field expressions joined by `AND`.
    The field expression must specify:
    1. The field name.
    2. An operator:
       - `=`, `!=`, `CONTAINS`, for single values.
       - `IN` or `NOT IN` for lists of values.
    3. The value. String values must be encosed in `"`, boolean values are {`true`, `false`}, timestamp values in ISO-8601.

    Currently supported fields:
    - `id` [yandex.cloud.loadtesting.api.v1.regression.Dashboard.id]
      - operators: `=`, `!=`, `IN`, `NOT IN`
    - `name` [yandex.cloud.loadtesting.api.v1.regression.Dashboard.name]
      - operators: `=`, `!=`, `IN`, `NOT IN`, `CONTAINS`

    Examples: 
    - `id IN ("1", "2", "3")`
    - `name CONTAINS "my-dashboard" AND id NOT IN ("4", "5")`
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListRegressionDashboardsRequest = ListRegressionDashboardsRequest

@typing.final
class ListRegressionDashboardsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListRegressionDashboardsRequest.page_size], use `next_page_token` as the value
    for the [ListRegressionDashboardsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def dashboards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.regression.dashboard_pb2.Dashboard]:
        """List of dashboards in the specified folder."""

    def __init__(
        self,
        *,
        dashboards: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.regression.dashboard_pb2.Dashboard] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboards", b"dashboards", "next_page_token", b"next_page_token"]) -> None: ...

global___ListRegressionDashboardsResponse = ListRegressionDashboardsResponse

@typing.final
class UpdateRegressionDashboardRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """ID of the dashboards to update."""
    etag: builtins.str
    """The current etag of the dashboard."""
    name: builtins.str
    """New name of the dashboard."""
    description: builtins.str
    """New description of the dashboard."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the dashboard are going to be updated."""

    @property
    def content(self) -> yandex.cloud.loadtesting.api.v1.regression.dashboard_pb2.Dashboard.Content:
        """New content of the dashboard."""

    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
        etag: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        content: yandex.cloud.loadtesting.api.v1.regression.dashboard_pb2.Dashboard.Content | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["content", b"content", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "dashboard_id", b"dashboard_id", "description", b"description", "etag", b"etag", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateRegressionDashboardRequest = UpdateRegressionDashboardRequest

@typing.final
class UpdateRegressionDashboardMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DASHBOARD_ID_FIELD_NUMBER: builtins.int
    dashboard_id: builtins.str
    """ID of the dashboard that is being updated."""
    def __init__(
        self,
        *,
        dashboard_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dashboard_id", b"dashboard_id"]) -> None: ...

global___UpdateRegressionDashboardMetadata = UpdateRegressionDashboardMetadata
